==> blesta-5.10.2.zip: blesta/plugins/domains/language/uk_ua/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.uk_ua
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.edit.text_registration_date'] = 'Дата реєстрації:';
$lang['AdminMain.index.text_date_added'] = 'Дата додана:';
$lang['AdminMain.index.heading_dateregistration'] = 'Дата реєстрації';
$lang['AdminMain.index.heading_registrar'] = 'Реєстратор';
$lang['AdminMain.!success.domain_registrar_updated'] = 'Оновлено реєстратора домену!';
$lang['AdminMain.add_confirmation.field_domain'] = 'Домен:';
$lang['AdminMain.getmodulefields.auto_choose'] = '-- Вибрати автоматично --';
$lang['AdminMain.edit.title_basic_options'] = 'Основні опції';
$lang['AdminMain.edit.title_actions'] = 'Дії';
$lang['AdminMain.edit.title_domain_information'] = 'Інформація про домен';
$lang['AdminMain.edit.term_years'] = '%1$s Роки';
$lang['AdminMain.edit.term_year'] = '%1$s Рік';
$lang['AdminMain.edit.term_months'] = '%1$s Місяці';
$lang['AdminMain.edit.term_month'] = '%1$s Month';
$lang['AdminMain.edit.term_weeks'] = '%1$s Тижні';
$lang['AdminMain.edit.term_week'] = 'Тиждень %1$s';
$lang['AdminMain.edit.term_days'] = '%1$s днів';
$lang['AdminMain.edit.term_day'] = '%1$s Day';
$lang['AdminMain.edit.text_date_canceled'] = 'Дата скасування:';
$lang['AdminMain.edit.text_date_suspended'] = 'Дата призупинення:';
$lang['AdminMain.edit.text_date_last_renewed'] = 'Остання дата поновлення:';
$lang['AdminMain.edit.text_never'] = 'Ніколи.';
$lang['AdminMain.edit.text_date_expires'] = 'Термін дії закінчується:';
$lang['AdminMain.edit.text_date_renews'] = 'Дата поновлюється:';
$lang['AdminMain.edit.text_date_added'] = 'Дата створення:';
$lang['AdminMain.edit.text_status'] = 'Статус:';
$lang['AdminMain.edit.text_years'] = 'Зареєстровані роки:';
$lang['AdminMain.edit.text_registrar'] = 'Реєстратор:';
$lang['AdminMain.edit.text_domain'] = 'Домен:';
$lang['AdminMain.edit.field_edit_service'] = 'Сервіс редагування';
$lang['AdminMain.edit.field_activate'] = 'Активувати';
$lang['AdminMain.edit.field_submit'] = 'Оновлення';
$lang['AdminMain.edit.field_notify_order'] = 'Після активації надішліть підтвердження замовлення на електронну пошту';
$lang['AdminMain.edit.field_use_module'] = 'Модуль використання';
$lang['AdminMain.edit.field_module'] = 'Модуль реєстратора';
$lang['AdminMain.edit.field_client'] = 'Клієнт';
$lang['AdminMain.edit.field_ns5'] = 'Сервер імен 5';
$lang['AdminMain.edit.field_ns4'] = 'Сервер імен 4';
$lang['AdminMain.edit.field_ns3'] = 'Сервер імен 3';
$lang['AdminMain.edit.field_ns2'] = 'Сервер імен 2';
$lang['AdminMain.edit.field_ns1'] = 'Сервер імен 1';
$lang['AdminMain.edit.field_auto_renewal'] = 'Увімкнути автоподовження';
$lang['AdminMain.edit.field_years'] = 'Роки';
$lang['AdminMain.edit.field_action'] = 'Дія';
$lang['AdminMain.edit.link_viewclient'] = 'Переглянути клієнта';
$lang['AdminMain.edit.boxtitle_edit'] = 'Редагувати домен: %1$s';
$lang['AdminMain.edit.boxtitle_client'] = 'Клієнт #%1$s';
$lang['AdminMain.add_confirmation.discount'] = 'Знижка:';
$lang['AdminMain.add_confirmation.subtotal'] = 'Проміжний підсумок:';
$lang['AdminMain.add_confirmation.price'] = 'Ціна';
$lang['AdminMain.add_confirmation.qty'] = 'Кількість';
$lang['AdminMain.add_confirmation.description'] = 'Опис';
$lang['AdminMain.add_confirmation.type_transfer'] = 'Переказ';
$lang['AdminMain.add_confirmation.type_register'] = 'Реєстрація';
$lang['AdminMain.add_confirmation.field_edit'] = 'Редагувати';
$lang['AdminMain.add_confirmation.field_add'] = 'Додати домен';
$lang['AdminMain.add_confirmation.field_update_coupon'] = 'Оновлення';
$lang['AdminMain.add_confirmation.field_coupon_code'] = 'Код купона';
$lang['AdminMain.add_confirmation.field_price'] = 'Ціна:';
$lang['AdminMain.add_confirmation.field_type'] = 'Друкуй:';
$lang['AdminMain.add_confirmation.field_years'] = 'Роками:';
$lang['AdminMain.add_confirmation.field_notify_order_false'] = 'Ні.';
$lang['AdminMain.add_confirmation.field_notify_order_true'] = 'Так.';
$lang['AdminMain.add_confirmation.field_notify_order'] = 'Надішліть електронний лист з підтвердженням замовлення:';
$lang['AdminMain.add_confirmation.field_module'] = 'Модуль реєстратора:';
$lang['AdminMain.add_confirmation.field_status'] = 'Статус:';
$lang['AdminMain.add_confirmation.field_invoice_method_dont'] = 'Не виставляти рахунок';
$lang['AdminMain.add_confirmation.field_invoice_method_append'] = 'Додати до інвойсу %1$s';
$lang['AdminMain.add_confirmation.field_invoice_method_create'] = 'Створити новий інвойс';
$lang['AdminMain.add_confirmation.field_invoice_method'] = 'Метод рахунків-фактур:';
$lang['AdminMain.add.edit_package_pricing'] = 'Редагувати ціноутворення';
$lang['AdminMain.add.term_recurring'] = '%1$s @ %2$s (поновлюється @ %3$s)';
$lang['AdminMain.add.term'] = '%1$s @ %2$s';
$lang['AdminMain.add.order_btn'] = 'Вибране замовлення';
$lang['AdminMain.add.term_years'] = '%1$s Роки';
$lang['AdminMain.add.term_year'] = '%1$s Рік';
$lang['AdminMain.add.term_months'] = '%1$s Місяці';
$lang['AdminMain.add.term_month'] = '%1$s Month';
$lang['AdminMain.add.term_weeks'] = '%1$s Тижні';
$lang['AdminMain.add.term_week'] = 'Тиждень %1$s';
$lang['AdminMain.add.term_days'] = '%1$s днів';
$lang['AdminMain.add.term_day'] = '%1$s Day';
$lang['AdminMain.add.text_domain_unavailable'] = 'Недоступно';
$lang['AdminMain.add.text_domain_available'] = 'Доступно';
$lang['AdminMain.add.heading_options'] = 'Параметри';
$lang['AdminMain.add.heading_status'] = 'Статус';
$lang['AdminMain.add.heading_domain'] = 'Домен';
$lang['AdminMain.add.title_registrar_options'] = 'Параметри реєстратора';
$lang['AdminMain.add.title_basic_options'] = 'Основні опції';
$lang['AdminMain.add.title_search_results'] = 'Результати пошуку';
$lang['AdminMain.add.field_notify_order'] = 'Після активації надішліть підтвердження замовлення на електронну пошту';
$lang['AdminMain.add.field_use_module'] = 'Надання домену за допомогою модуля реєстратора при активації';
$lang['AdminMain.add.field_module'] = 'Модуль реєстратора';
$lang['AdminMain.add.field_status'] = 'Статус';
$lang['AdminMain.add.field_years'] = 'Роки';
$lang['AdminMain.add.field_invoice_method_dont'] = 'Не виставляти рахунок';
$lang['AdminMain.add.field_invoice_method_append'] = 'Додати до існуючого інвойсу';
$lang['AdminMain.add.field_invoice_method_create'] = 'Створити новий інвойс';
$lang['AdminMain.add.field_invoice_method'] = 'Метод рахунків-фактур';
$lang['AdminMain.add.field_submit'] = 'Продовжуйте';
$lang['AdminMain.add.field_lookup'] = 'Перевірити наявність';
$lang['AdminMain.add.field_add'] = 'Додати домен';
$lang['AdminMain.add.field_register'] = 'Зареєструватися';
$lang['AdminMain.add.field_transfer'] = 'Переказ';
$lang['AdminMain.add.link_viewclient'] = 'Переглянути клієнта';
$lang['AdminMain.add.boxtitle_add'] = 'Додати домен: %1$s';
$lang['AdminMain.add.boxtitle_client'] = 'Клієнт #%1$s';
$lang['AdminMain.index.unparent'] = 'Непрозора та обнулена ціна';
$lang['AdminMain.!error.unsupported_domain'] = 'Доменне ім\'я не підтримується.';
$lang['AdminMain.!success.service_edited'] = 'Домен успішно оновлено!';
$lang['AdminMain.!success.domain_add'] = 'Домен успішно додано!';
$lang['AdminMain.!success.domain_transfer'] = 'Домен успішно перенесено!';
$lang['AdminMain.!success.domain_register'] = 'Домен успішно зареєстровано!';
$lang['AdminMain.!success.domains_unparented'] = 'Вибрані домени були видалені з батьківських сервісів і ціна була успішно скинута!';
$lang['AdminMain.getfilters.field_service_meta'] = 'Доменне ім\'я';
$lang['AdminMain.getfilters.field_package_name'] = 'TLD';
$lang['AdminMain.getfilters.any'] = 'Будь-який';
$lang['AdminMain.domains.action.field_client'] = 'Клієнт';
$lang['AdminMain.domains.action.field_nameservers'] = 'Сервери імен';
$lang['AdminMain.domains.action.field_years'] = 'Роки';
$lang['AdminMain.index.field_actionsubmit'] = 'Надіслати';
$lang['AdminMain.index.domain_push_to_client'] = 'Push до клієнта';
$lang['AdminMain.index.update_nameservers'] = 'Оновлення серверів імен';
$lang['AdminMain.index.domain_renewal'] = 'Поновити домен';
$lang['AdminMain.index.change_auto_renewal'] = 'Змінити автоматичне поновлення';
$lang['AdminMain.index.text_off'] = 'Вимкнено';
$lang['AdminMain.index.text_on'] = 'На';
$lang['AdminMain.index.text_never'] = 'Ніколи.';
$lang['AdminMain.index.no_results'] = 'Сервісів з таким статусом немає.';
$lang['AdminMain.index.confirm_delete'] = 'Ви впевнені, що хочете видалити цю послугу?';
$lang['AdminMain.index.option_delete'] = 'Видалити';
$lang['AdminMain.index.option_manage'] = 'Керувати';
$lang['AdminMain.index.option_parent'] = 'Батько';
$lang['AdminMain.index.recurring_term'] = '%1$s %2$s @ %3$s';
$lang['AdminMain.index.categorylink_newservice'] = 'Новий домен';
$lang['AdminMain.index.category_canceled'] = 'Скасовано';
$lang['AdminMain.index.category_suspended'] = 'Призупинено';
$lang['AdminMain.index.category_pending'] = 'На розгляді';
$lang['AdminMain.index.category_active'] = 'Активний';
$lang['AdminMain.index.heading_options'] = 'Параметри';
$lang['AdminMain.index.heading_datecanceled'] = 'Дата скасована';
$lang['AdminMain.index.heading_datesuspended'] = 'Дата призупинена';
$lang['AdminMain.index.heading_dateexpires'] = 'Дата закінчення терміну дії';
$lang['AdminMain.index.heading_daterenews'] = 'Поновлення дати';
$lang['AdminMain.index.heading_datecreated'] = 'Дата створення';
$lang['AdminMain.index.heading_term'] = 'Термін';
$lang['AdminMain.index.heading_domain'] = 'Домен';
$lang['AdminMain.index.heading_status'] = 'Статус';
$lang['AdminMain.index.heading_addons'] = 'Доповнення';
$lang['AdminMain.index.boxtitle_domains'] = 'Домени';
$lang['AdminMain.index.page_title'] = 'Домени клієнта #%1$s';
$lang['AdminMain.!success.domains_pushed'] = 'Вибрані домени були успішно передані новому клієнту.';
$lang['AdminMain.!success.update_nameservers'] = 'Оновлені сервери доменних імен!';
$lang['AdminMain.!success.domain_renewal'] = 'Домен продовжено!';
$lang['AdminMain.!success.change_auto_renewal'] = 'Оновлена функція автоматичного продовження домену!';

==> blesta-5.11.4.zip: blesta/plugins/domains/language/uk_ua/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.uk_ua
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.edit.text_registration_date'] = 'Дата реєстрації:';
$lang['AdminMain.index.text_date_added'] = 'Дата додана:';
$lang['AdminMain.index.heading_dateregistration'] = 'Дата реєстрації';
$lang['AdminMain.index.heading_registrar'] = 'Реєстратор';
$lang['AdminMain.!success.domain_registrar_updated'] = 'Оновлено реєстратора домену!';
$lang['AdminMain.add_confirmation.field_domain'] = 'Домен:';
$lang['AdminMain.getmodulefields.auto_choose'] = '-- Вибрати автоматично --';
$lang['AdminMain.edit.title_basic_options'] = 'Основні опції';
$lang['AdminMain.edit.title_actions'] = 'Дії';
$lang['AdminMain.edit.title_domain_information'] = 'Інформація про домен';
$lang['AdminMain.edit.term_years'] = '%1$s Роки';
$lang['AdminMain.edit.term_year'] = '%1$s Рік';
$lang['AdminMain.edit.term_months'] = '%1$s Місяці';
$lang['AdminMain.edit.term_month'] = '%1$s Month';
$lang['AdminMain.edit.term_weeks'] = '%1$s Тижні';
$lang['AdminMain.edit.term_week'] = 'Тиждень %1$s';
$lang['AdminMain.edit.term_days'] = '%1$s днів';
$lang['AdminMain.edit.term_day'] = '%1$s Day';
$lang['AdminMain.edit.text_date_canceled'] = 'Дата скасування:';
$lang['AdminMain.edit.text_date_suspended'] = 'Дата призупинення:';
$lang['AdminMain.edit.text_date_last_renewed'] = 'Остання дата поновлення:';
$lang['AdminMain.edit.text_never'] = 'Ніколи.';
$lang['AdminMain.edit.text_date_expires'] = 'Термін дії закінчується:';
$lang['AdminMain.edit.text_date_renews'] = 'Дата поновлюється:';
$lang['AdminMain.edit.text_date_added'] = 'Дата створення:';
$lang['AdminMain.edit.text_status'] = 'Статус:';
$lang['AdminMain.edit.text_years'] = 'Зареєстровані роки:';
$lang['AdminMain.edit.text_registrar'] = 'Реєстратор:';
$lang['AdminMain.edit.text_domain'] = 'Домен:';
$lang['AdminMain.edit.field_edit_service'] = 'Сервіс редагування';
$lang['AdminMain.edit.field_activate'] = 'Активувати';
$lang['AdminMain.edit.field_submit'] = 'Оновлення';
$lang['AdminMain.edit.field_notify_order'] = 'Після активації надішліть підтвердження замовлення на електронну пошту';
$lang['AdminMain.edit.field_use_module'] = 'Модуль використання';
$lang['AdminMain.edit.field_module'] = 'Модуль реєстратора';
$lang['AdminMain.edit.field_client'] = 'Клієнт';
$lang['AdminMain.edit.field_ns5'] = 'Сервер імен 5';
$lang['AdminMain.edit.field_ns4'] = 'Сервер імен 4';
$lang['AdminMain.edit.field_ns3'] = 'Сервер імен 3';
$lang['AdminMain.edit.field_ns2'] = 'Сервер імен 2';
$lang['AdminMain.edit.field_ns1'] = 'Сервер імен 1';
$lang['AdminMain.edit.field_auto_renewal'] = 'Увімкнути автоподовження';
$lang['AdminMain.edit.field_years'] = 'Роки';
$lang['AdminMain.edit.field_action'] = 'Дія';
$lang['AdminMain.edit.link_viewclient'] = 'Переглянути клієнта';
$lang['AdminMain.edit.boxtitle_edit'] = 'Редагувати домен: %1$s';
$lang['AdminMain.edit.boxtitle_client'] = 'Клієнт #%1$s';
$lang['AdminMain.add_confirmation.discount'] = 'Знижка:';
$lang['AdminMain.add_confirmation.subtotal'] = 'Проміжний підсумок:';
$lang['AdminMain.add_confirmation.price'] = 'Ціна';
$lang['AdminMain.add_confirmation.qty'] = 'Кількість';
$lang['AdminMain.add_confirmation.description'] = 'Опис';
$lang['AdminMain.add_confirmation.type_transfer'] = 'Переказ';
$lang['AdminMain.add_confirmation.type_register'] = 'Реєстрація';
$lang['AdminMain.add_confirmation.field_edit'] = 'Редагувати';
$lang['AdminMain.add_confirmation.field_add'] = 'Додати домен';
$lang['AdminMain.add_confirmation.field_update_coupon'] = 'Оновлення';
$lang['AdminMain.add_confirmation.field_coupon_code'] = 'Код купона';
$lang['AdminMain.add_confirmation.field_price'] = 'Ціна:';
$lang['AdminMain.add_confirmation.field_type'] = 'Друкуй:';
$lang['AdminMain.add_confirmation.field_years'] = 'Роками:';
$lang['AdminMain.add_confirmation.field_notify_order_false'] = 'Ні.';
$lang['AdminMain.add_confirmation.field_notify_order_true'] = 'Так.';
$lang['AdminMain.add_confirmation.field_notify_order'] = 'Надішліть електронний лист з підтвердженням замовлення:';
$lang['AdminMain.add_confirmation.field_module'] = 'Модуль реєстратора:';
$lang['AdminMain.add_confirmation.field_status'] = 'Статус:';
$lang['AdminMain.add_confirmation.field_invoice_method_dont'] = 'Не виставляти рахунок';
$lang['AdminMain.add_confirmation.field_invoice_method_append'] = 'Додати до інвойсу %1$s';
$lang['AdminMain.add_confirmation.field_invoice_method_create'] = 'Створити новий інвойс';
$lang['AdminMain.add_confirmation.field_invoice_method'] = 'Метод рахунків-фактур:';
$lang['AdminMain.add.edit_package_pricing'] = 'Редагувати ціноутворення';
$lang['AdminMain.add.term_recurring'] = '%1$s @ %2$s (поновлюється @ %3$s)';
$lang['AdminMain.add.term'] = '%1$s @ %2$s';
$lang['AdminMain.add.order_btn'] = 'Вибране замовлення';
$lang['AdminMain.add.term_years'] = '%1$s Роки';
$lang['AdminMain.add.term_year'] = '%1$s Рік';
$lang['AdminMain.add.term_months'] = '%1$s Місяці';
$lang['AdminMain.add.term_month'] = '%1$s Month';
$lang['AdminMain.add.term_weeks'] = '%1$s Тижні';
$lang['AdminMain.add.term_week'] = 'Тиждень %1$s';
$lang['AdminMain.add.term_days'] = '%1$s днів';
$lang['AdminMain.add.term_day'] = '%1$s Day';
$lang['AdminMain.add.text_domain_unavailable'] = 'Недоступно';
$lang['AdminMain.add.text_domain_available'] = 'Доступно';
$lang['AdminMain.add.heading_options'] = 'Параметри';
$lang['AdminMain.add.heading_status'] = 'Статус';
$lang['AdminMain.add.heading_domain'] = 'Домен';
$lang['AdminMain.add.title_registrar_options'] = 'Параметри реєстратора';
$lang['AdminMain.add.title_basic_options'] = 'Основні опції';
$lang['AdminMain.add.title_search_results'] = 'Результати пошуку';
$lang['AdminMain.add.field_notify_order'] = 'Після активації надішліть підтвердження замовлення на електронну пошту';
$lang['AdminMain.add.field_use_module'] = 'Надання домену за допомогою модуля реєстратора при активації';
$lang['AdminMain.add.field_module'] = 'Модуль реєстратора';
$lang['AdminMain.add.field_status'] = 'Статус';
$lang['AdminMain.add.field_years'] = 'Роки';
$lang['AdminMain.add.field_invoice_method_dont'] = 'Не виставляти рахунок';
$lang['AdminMain.add.field_invoice_method_append'] = 'Додати до існуючого інвойсу';
$lang['AdminMain.add.field_invoice_method_create'] = 'Створити новий інвойс';
$lang['AdminMain.add.field_invoice_method'] = 'Метод рахунків-фактур';
$lang['AdminMain.add.field_submit'] = 'Продовжуйте';
$lang['AdminMain.add.field_lookup'] = 'Перевірити наявність';
$lang['AdminMain.add.field_add'] = 'Додати домен';
$lang['AdminMain.add.field_register'] = 'Зареєструватися';
$lang['AdminMain.add.field_transfer'] = 'Переказ';
$lang['AdminMain.add.link_viewclient'] = 'Переглянути клієнта';
$lang['AdminMain.add.boxtitle_add'] = 'Додати домен: %1$s';
$lang['AdminMain.add.boxtitle_client'] = 'Клієнт #%1$s';
$lang['AdminMain.index.unparent'] = 'Непрозора та обнулена ціна';
$lang['AdminMain.!error.unsupported_domain'] = 'Доменне ім\'я не підтримується.';
$lang['AdminMain.!success.service_edited'] = 'Домен успішно оновлено!';
$lang['AdminMain.!success.domain_add'] = 'Домен успішно додано!';
$lang['AdminMain.!success.domain_transfer'] = 'Домен успішно перенесено!';
$lang['AdminMain.!success.domain_register'] = 'Домен успішно зареєстровано!';
$lang['AdminMain.!success.domains_unparented'] = 'Вибрані домени були видалені з батьківських сервісів і ціна була успішно скинута!';
$lang['AdminMain.getfilters.field_service_meta'] = 'Доменне ім\'я';
$lang['AdminMain.getfilters.field_package_name'] = 'TLD';
$lang['AdminMain.getfilters.any'] = 'Будь-який';
$lang['AdminMain.domains.action.field_client'] = 'Клієнт';
$lang['AdminMain.domains.action.field_nameservers'] = 'Сервери імен';
$lang['AdminMain.domains.action.field_years'] = 'Роки';
$lang['AdminMain.index.field_actionsubmit'] = 'Надіслати';
$lang['AdminMain.index.domain_push_to_client'] = 'Push до клієнта';
$lang['AdminMain.index.update_nameservers'] = 'Оновлення серверів імен';
$lang['AdminMain.index.domain_renewal'] = 'Поновити домен';
$lang['AdminMain.index.change_auto_renewal'] = 'Змінити автоматичне поновлення';
$lang['AdminMain.index.text_off'] = 'Вимкнено';
$lang['AdminMain.index.text_on'] = 'На';
$lang['AdminMain.index.text_never'] = 'Ніколи.';
$lang['AdminMain.index.no_results'] = 'Сервісів з таким статусом немає.';
$lang['AdminMain.index.confirm_delete'] = 'Ви впевнені, що хочете видалити цю послугу?';
$lang['AdminMain.index.option_delete'] = 'Видалити';
$lang['AdminMain.index.option_manage'] = 'Керувати';
$lang['AdminMain.index.option_parent'] = 'Батько';
$lang['AdminMain.index.recurring_term'] = '%1$s %2$s @ %3$s';
$lang['AdminMain.index.categorylink_newservice'] = 'Новий домен';
$lang['AdminMain.index.category_canceled'] = 'Скасовано';
$lang['AdminMain.index.category_suspended'] = 'Призупинено';
$lang['AdminMain.index.category_pending'] = 'На розгляді';
$lang['AdminMain.index.category_active'] = 'Активний';
$lang['AdminMain.index.heading_options'] = 'Параметри';
$lang['AdminMain.index.heading_datecanceled'] = 'Дата скасована';
$lang['AdminMain.index.heading_datesuspended'] = 'Дата призупинена';
$lang['AdminMain.index.heading_dateexpires'] = 'Дата закінчення терміну дії';
$lang['AdminMain.index.heading_daterenews'] = 'Поновлення дати';
$lang['AdminMain.index.heading_datecreated'] = 'Дата створення';
$lang['AdminMain.index.heading_term'] = 'Термін';
$lang['AdminMain.index.heading_domain'] = 'Домен';
$lang['AdminMain.index.heading_status'] = 'Статус';
$lang['AdminMain.index.heading_addons'] = 'Доповнення';
$lang['AdminMain.index.boxtitle_domains'] = 'Домени';
$lang['AdminMain.index.page_title'] = 'Домени клієнта #%1$s';
$lang['AdminMain.!success.domains_pushed'] = 'Вибрані домени були успішно передані новому клієнту.';
$lang['AdminMain.!success.update_nameservers'] = 'Оновлені сервери доменних імен!';
$lang['AdminMain.!success.domain_renewal'] = 'Домен продовжено!';
$lang['AdminMain.!success.change_auto_renewal'] = 'Оновлена функція автоматичного продовження домену!';
$lang['AdminMain.edit.field_registration_date'] = 'Змінити дату реєстрації';
$lang['AdminMain.edit.field_expiration_date'] = 'Змінити термін дії';
$lang['AdminMain.!success.change_registration_date'] = 'Оновлено дату реєстрації домену!';
$lang['AdminMain.!success.change_expiration_date'] = 'Оновлена дата закінчення терміну дії домену!';
